import django
import django.dispatch


if django.VERSION >= (4, 0):
    transaction_started = django.dispatch.Signal()
    transaction_succeeded = django.dispatch.Signal()
    transaction_failed = django.dispatch.Signal()

    auth_started = django.dispatch.Signal()
    auth_succeeded = django.dispatch.Signal()
    auth_failed = django.dispatch.Signal()
else:
    transaction_started = django.dispatch.Signal(providing_args=["transaction"])
    transaction_succeeded = django.dispatch.Signal(providing_args=["transaction"])
    transaction_failed = django.dispatch.Signal(providing_args=["transaction"])

    auth_started = django.dispatch.Signal(providing_args=["auth"])
    auth_succeeded = django.dispatch.Signal(providing_args=["auth"])
    auth_failed = django.dispatch.Signal(providing_args=["auth"])



import django

from thorbanks.views import response


if django.VERSION >= (4, 0):
    from django.urls import re_path

    urlpatterns = [
        re_path(r"^thorbanks_response/$", response, name="thorbanks_response"),
    ]
else:
    from django.conf.urls import url

    urlpatterns = [
        url(r"^thorbanks_response/$", response, name="thorbanks_response"),
    ]
